\name{car.test.frame}
\alias{car.test.frame}
\non_function{}
\title{Automobile Data from `Consumer Reports' 1990}
\description{
  The \code{car.test.frame} data frame has 60 rows and 8 columns,
  giving data on makes of cars taken from the April, 1990 issue of
  \emph{Consumer Reports}. 
}
\usage{
data(car.test.frame)
}
\format{
This data frame contains the following columns:
\describe{
\item{\code{Price}}{
a numeric vector giving the list price in US dollars of a standard model
}
\item{\code{Country}}{
of origin, a factor with levels
\code{France} 
\code{Germany} 
\code{Japan} 
\code{Japan/USA} 
\code{Korea} 
\code{Mexico} 
\code{Sweden} 
\code{USA} 
}
\item{\code{Reliability}}{
a numeric vector coded \code{1} to \code{5}.
}
\item{\code{Mileage}}{
fuel consumption miles per US gallon, as tested. 
}
\item{\code{Type}}{
a factor with levels
\code{Compact} 
\code{Large} 
\code{Medium} 
\code{Small} 
\code{Sporty} 
\code{Van} 
}
\item{\code{Weight}}{
kerb weight in pounds.
}
\item{\code{Disp.}}{
the engine capacity (displacement) in litres.
}
\item{\code{HP}}{
the net horsepower of the vehicle.
}
}}
\source{
  \emph{Consumer Reports}, April, 1990, pp. 235--288 quoted in

  John M. Chambers and Trevor J. Hastie eds. (1992)
  \emph{Statistical Models in S}, Wadsworth and Brooks/Cole,
  Pacific Grove, CA 1992, pp. 46--47.
}

\examples{
data(car.test.frame)
z.auto <- rpart(Mileage ~ Weight, car.test.frame)
summary(z.auto)
}
\keyword{datasets}

\eof
\name{cmds.diss}
\alias{cmds.diss}
\title{Classical Scaling of Dissimilarity Measures}
\description{
  The function first computes the dissimilarity matrix according to the specified method -- 
  see \code{\link[mvpart]{gdist}} or \code{\link[mvpart]{xdiss}}. The dissimilarities are then
  scaled using classical scaling -- see \code{\link[mva]{cmdscale}}. The returned matrix can be input into
  \code{\link[mvpart]{rpart}} or \code{\link[mvpart]{mvpart}} for multivariate regression tree splitting.
  
}
\usage{
cmds.diss(data, k = ncol(data), x.use = FALSE, method = "man", 
    zero.chk = TRUE, plt = FALSE, plot.subset = FALSE, plot.subn = 5) 
}

\arguments{
  \item{data}{ Data matrix}
  \item{k}{ Number of vectors to be returned}
  \item{x.use}{ Use extended dissimilarity?}
  \item{method}{ Dissimilarity index }
  \item{zero.chk}{ Check for zero row sums -- if zero ignore these rows according to method}
  \item{plt}{ Plot the relationship between the dissimilarities and the distances calculated 
  from the scaled output vectors. }
  \item{plot.subset}{ Plot a subset of the points -- useful for large data sets. }
  \item{plot.subn}{ Controls how many points are plotted when \code{plot.subset}=TRUE.
  The number of points plotted is 750 + N * plot.subn where N = number of rows in \code{data}.
}
}

\details{
  The function knows the same dissimilarity indices as \code{\link[mvpart]{gdist}}.
  Plotting the relationship between the dissimilarities and the distances calculated 
  from the scaled output vectors is useful in assessing potential loss of information.
  If the loss is high then the results from partitioning directly from the dissimilarity 
  matrix using distance-base partitioning (see \code{dist} in \code{\link[mvpart]{rpart}}),and those 
  obtained from partitioning the output of cmds.diss using multivariate regression trees
  (see \code{mrt} in \code{\link[mvpart]{rpart}}) can be substantial.
       
}

\author{ Glenn De'ath }

\examples{
data(spider)
dist.vecs <- cmds.diss(spider)

# comparing splitting using "dist" and "mrt" methods 
# for euclidean distance the answers are indentical :
# first using "mrt" on the data directly
mvpart(data.matrix(spider[,1:12])~water+twigs+reft+herbs+moss+sand,spider,method="mrt",size=5)

# now using "dist" -- note we need the full distance matrix squared
mvpart(gdist(spider[,1:12],meth="euc",full=TRUE,sq=TRUE)~water+twigs+reft+herbs+moss+sand,spider,method="dist",size=5)

# finally using "mrt" from the scaled dissimilarities.
mvpart(cmds.diss(spider[,1:12],meth="euc")~water+twigs+reft+herbs+moss+sand,spider,method="mrt",size=5)

# try with some other measure of dissimilarity eg extended bray-curtis -- the result will differ
# between methods

}

\keyword{ multivariate }%-- one or more ...

\eof
\name{descendants}
\alias{descendants}
\title{
  Descendants
}
\description{
  Internal function for Rpart
}

\details{
  \code{descendants} is to be used only internally.
}
\keyword{internal}


\eof
\name{distfull}
\alias{distfull}
\title{
  Distfull
}
\description{
  Internal function for Rpart
}

\details{
  \code{distfull} is to be used only internally.
}
\keyword{internal}


\eof
\name{eqscplt}
\alias{eqscplt}
\title{
  Eqscplt
}
\description{
  Internal function for Rpart
}

\details{
  \code{eqscplt} is to be used only internally.
}
\keyword{internal}


\eof
\name{formatg}
\alias{formatg}
\title{
  Formatg
}
\description{
  Internal function for Rpart
}

\details{
  \code{formatg} is to be used only internally.
}
\keyword{internal}


\eof
\name{gdist}
\alias{gdist}
\title{Dissimilarity Measures}
\description{
  The function computes useful dissimilarity indices which are known
  to have a good rank-order relation with gradient separation and are
  thus efficient in community ordination with multidimensional scaling.
}
\usage{
gdist(x, method="bray", keepdiag=FALSE, full=FALSE, sq=FALSE)
}

\arguments{
  \item{x}{ Data matrix}
  \item{method}{ Dissimilarity index }
  \item{keepdiag}{ Compute amd keep diagonals}
  \item{full}{ Return the square dissimilarity matrix}
  \item{sq}{ Square the dissimilarities -- useful for distance-based partitioning}
}

\details{
  The function knows the following dissimilarity indices:
  \tabular{ll}{
    \code{euclidean}
    \tab \eqn{d_{jk} = \sqrt{\sum_i (x_{ij}-x_{ik})^2}}{d[jk] = sqrt(sum (x[ij]-x[ik])^2)}
    \cr
    \code{manhattan}
    \tab \eqn{d_{jk} = \sum_i |x_{ij} - x_{ik}|}{d[jk] = sum(abs(x[ij] -
      x[ik]))}
    \cr
    \code{gower}
    \tab \eqn{d_{jk} = \sum_i \frac{|x_{ij}-x_{ik}|}{\max_i-\min_i}}{d[jk] = sum (abs(x[ij]-x[ik])/(max(i)-min(i))}
    \cr
    \code{canberra}
    \tab \eqn{d_{jk}=\frac{1}{N-Z} \sum_i
      \frac{|x_{ij}-x_{ik}|}{x_{ij}+x_{ik}}}{d[jk] = (1/NZ) sum ((x[ij]-x[ik])/(x[ij]+x[ik]))}
    \cr
    \code{bray}
    \tab \eqn{d_{jk} = \frac{\sum_i |x_{ij}-x_{ik}|}{\sum_i (x_{ij}+x_{ik})}}{d[jk] = (sum abs(x[ij]-x[ik])/(sum (x[ij]+x[ik]))}
    \cr
    \code{kulczynski}
    \tab \eqn{d_{jk} = 1-0.5(\frac{\sum_i \min(x_{ij},x_{ik})}{\sum_i x_{ij}} +
      \frac{\sum_i \min(x_{ij},x_{ik})}{\sum_i x_{ik}} )}{d[jk] 1 - 0.5*((sum min(x[ij],x[ik])/(sum x[ij]) + (sum
      min(x[ij],x[ik])/(sum x[ik]))}
	\cr
  	\code{maximum}
    \tab \eqn{d_{jk} = \max_i |x_{ij} - x_{ik}|}{d[jk] = max(abs(x[ij] -
      x[ik]))}
    \cr
	\code{binary}
    \tab \eqn{d_{jk} = \sum_i |x_{ij}>0 - x_{ik}>0|}{d[jk] = max(abs(x[ij]>0 -
      x[ik]>0))}
    \cr
    \code{chord}
    \tab \eqn{d_{jk} = \sqrt{\sum_i (x_{ij}-x_{ik})^2} / {\sum_i (x_{ij}+x_{ik})^2}}{d[jk] = sqrt((sum (x[ij]-x[ik])^2)/(sum (x[ij]+x[ik])^2))}
    \cr
    }
    
  where \eqn{N-Z}{NZ} is the number of non-zero entries.

  Infamous ''double zeros'' are removed in Canberra dissimilarity.

  Euclidean and Manhattan dissimilarities are not good in gradient
  separation without proper standardization but are still included for
  comparison and special needs.

  Some of indices become identical or rank-order similar after some
  standardizations. 
}
\value{
  Should be interchangeable with \code{\link[mva]{dist}} and returns a
  distance object of the same type.
}
\references{ Faith, D.P, Minchin, P.R. and Belbin, L. (1987)
  Compositional dissimilarity as a robust measure of ecological
  distance. \emph{Vegetatio} 69, 57-68. }

\author{ Jari Oksanen  -- modified Glenn De'ath (Dec 03)}

\note{The  function is an alternative to \code{\link[mva]{dist}} adding
  some ecologically meaningful indices.  Both methods should produce
  similar types of objects which can be interchanged in any method
  accepting either.  Manhattan and Euclidean dissimilarities should be
  identical in both methods, and Canberra dissimilary may be similar.
}

\examples{
data(spider)
spider.dist <- gdist(spider[1:12,])
}
\keyword{ multivariate }%-- one or more ...

\eof
\name{kyphosis}
\alias{kyphosis}
\non_function{}
\title{Data on Children who have had Corrective Spinal Surgery}
\description{
  The \code{kyphosis} data frame has 81 rows and 4 columns.
  representing data on children who have had corrective spinal surgery
}
\usage{
data(kyphosis)
}
\format{
This data frame contains the following columns:
\describe{
\item{\code{Kyphosis}}{
a factor with levels
\code{absent} 
\code{present}
indicating if a kyphosis (a type of deformation)
was present after the operation.
}
\item{\code{Age}}{
in months
}
\item{\code{Number}}{
the number of vertebrae involved 
}
\item{\code{Start}}{
the number of the first (topmost) vertebra operated on.
}
}}
\source{
   John M. Chambers and Trevor J. Hastie eds. (1992)
  \emph{Statistical Models in S}, Wadsworth and Brooks/Cole,
  Pacific Grove, CA 1992.
}
\examples{
data(kyphosis)
fit <- rpart(Kyphosis ~ Age + Number + Start, data=kyphosis)
fit2 <- rpart(Kyphosis ~ Age + Number + Start, data=kyphosis,
              parms=list(prior=c(.65,.35), split='information'))
fit3 <- rpart(Kyphosis ~ Age + Number + Start, data=kyphosis,
              control=rpart.control(cp=.05))
par(mfrow=c(1,2))
plot(fit)
text(fit, use.n=TRUE)
plot(fit2)
text(fit2, use.n=TRUE)
}
\keyword{datasets}

\eof
\name{labels.rpart}
\alias{labels.rpart}
\title{
  Create Split Labels For an Rpart Object 
}
\description{
This function provides labels for the branches of an
 \code{rpart} tree.
}
\usage{
\method{labels}{rpart}(object, digits=4, minlength=1, pretty, collapse=TRUE, ...)
}
\arguments{
\item{object}{
fitted model object of class \code{rpart}.  This is 
assumed to be the result 
of some function that produces an object with the same named 
components as that returned by the \code{rpart} function.
}
\item{digits}{
the number of digits to be used for numeric values.  
All of the \code{rpart} functions that call labels
explicitly set this value, with \code{options("digits")}
as the default.
}
\item{minlength}{
the minimum length for abbreviation of character or factor variables.
If 0 no abbreviation is done; if 1 then single letters are used with
\code{"a"} for the first level, \code{"b"} for the second and so on.
If the value is greater than 1, the 
\code{abbreviate} function is used.
}
\item{pretty}{
an argument included for backwards compatibility:
\code{pretty=0} implies \code{minlength=0},
\code{pretty=NULL} implies \code{minlength=1}, and
\code{pretty=TRUE} implies \code{minlength=4}.
}
\item{collapse}{
logical.
The returned set of labels is always of the same length as the number
of nodes in the tree.  
If \code{collapse=TRUE} (default), 
the returned value is a vector of labels for the branch leading into
each node, with \code{"root"} as the label for the top node.
If \code{FALSE}, the returned value is a two
column matrix of labels for the left and right branches leading 
out from each node, with \code{"leaf"} as the branch labels for terminal
nodes.
}
\item{\dots}{
optional arguments to \code{abbreviate}.
}
}
\value{
Vector of split labels (\code{collapse=TRUE}) or matrix 
of left and right splits 
(\code{collapse=FALSE}) for the supplied 
\code{rpart} object.  This function is called 
by printing methods for \code{rpart} and is not 
intended to be called 
directly by the users. 
}
\seealso{
\code{\link{abbreviate}} 
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{meanvar.rpart}
\alias{meanvar}
\alias{meanvar.rpart}
\title{
  Mean-Variance Plot for an Rpart Object 
}
\description{
Creates a plot on the current graphics device of the deviance of the 
node divided by the number of observations at the node.  Also returns 
the node number. 
}
\usage{
\method{meanvar}{rpart}(tree, xlab="ave(y)", ylab="ave(deviance)", \dots)
}
\arguments{
\item{tree}{
fitted model object of class \code{rpart}.  This is asumed to be the result 
of some function that produces an object with the same named 
components as that returned by the \code{rpart} function. 
}
\item{xlab}{
x-axis label for the plot. 
}
\item{ylab}{
y-axis label for the plot. 
}
\item{\dots}{
additional graphical parameters may be supplied as arguments to this function. 
}
}
\value{
an invisible list containing the following vectors is returned. 

\item{x}{
fitted value at terminal nodes (\code{yval}). 
}
\item{y}{
deviance of node divided by number of observations at node. 
}
\item{label}{
node number. 
}
}
\section{Side Effects}{
a plot is put on the current graphics device. 
}
\seealso{
 \code{\link{plot.rpart}}.   
}
\examples{
data(car.test.frame)
z.auto <- rpart(Mileage ~ Weight, car.test.frame)
meanvar(z.auto, log='xy')
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{model.frame.rpart}
\alias{model.frame.rpart}
\title{
  Model.frame.rpart
}
\description{
  Internal function for Rpart
}

\details{
  \code{model.frame.rpart} is to be used only internally.
}
\keyword{internal}


\eof
\name{mvpart}
\alias{mvpart}
\title{
Recursive Partitioning and Regression Trees
}
\description{
Wrapper function for fitting and plotting \code{rpart} models 
}

\usage{
mvpart(form, data, minauto = TRUE, size, xv = c("1se", "min", "pick", "none"), 
    xval = 10, xvmult = 0, xvse = 1, snip = FALSE,
    plot.add = TRUE, text.add = TRUE, digits = 3, margin = 0, uniform = FALSE,
    which = 1, pretty = TRUE, use.n = TRUE, 
    all = FALSE, bord = FALSE, xadj = 1, yadj = 1, prn = FALSE, 
    branch = 1, rsq = FALSE, big.pts = FALSE, pca = FALSE, interact.pca = FALSE, 
    wgt.ave.pca = FALSE, \dots) 
}

\arguments{
\item{form}{
As for \code{rpart} function. 
Arguments to rpart can be passed by \dots.
}
\item{data}{
Optional data frame in which to interpret the variables named in the 
formula 
}
\item{minauto}{
If \code{TRUE} uses smart minsplit and minbucket based on N cases.
}
\item{size}{
The size of tree to be generated.
}
\item{xv}{
Selection of tree by cross-validation: \code{"1se"} - gives best tree within one SE of the overall best,
\code{"min"} - the best tree, \code{"pick"} - pick the tree size interactively,
\code{"none"} - no cross-validation.
}
\item{xval}{
Number of cross-validations or vector defining cross-validation groups.
}

\item{xvmult}{
Number of multiple cross-validations. 
}
\item{xvse}{
Multiplier for the number of SEs used for \code{xv = "1se"}.
}
\item{plot.add}{
Plot the tree and (optionally) add text.
}
\item{text.add}{
Add output of \code{text.rpart} to tree.
}
\item{snip}{
Interactively prune the tree.
}
\item{digits}{
Number of digits on labels.
}
\item{margin}{
Margin around plot, 0.1 gives an extra 10 percent space around the plot.
}
\item{uniform}{
Uniform lengths to the branches of the tree.
}
\item{which}{
Which split labels and where to plot them, 1=centered, 2 = left, 3 = right and 4 = both.
}
\item{pretty}{
Pretty labels or full labels.
}
\item{use.n}{
Add number of cases at each node.
}
\item{all}{
Annotate all nodes.
}
\item{bord}{
Border (box) around the barplots.
}
\item{xadj, yadj}{
Adjust the size of the individual barplots (default = 1).
}
\item{prn}{
If \code{TRUE} prints tree details.
}
\item{branch}{
Controls spread of branches: 1=vertical lines, 0=maximum slope.
}
\item{rsq}{
If \code{TRUE} gives "rsq" plot.
}
\item{big.pts}{
Plot colored points at leaves -- useful to link to PCA plot.
}
\item{pca}{
If \code{TRUE} plots PCA of group means and add species and site information.
}
\item{interact.pca}{
If \code{TRUE} runs interactive PCA. See \code{rpart.pca}.
}
\item{wgt.ave.pca}{
If \code{TRUE} plot weighted averages acorss sites for species.
}
\item{\dots}{
\dots other arguments passed to \code{rpart}.
}
}

\value{
an object of class \code{rpart}, a superset of class \code{tree}. 
}

\seealso{
  \code{\link{rpart}}, \code{\link{rpart.pca}},
}
\examples{
data(spider)
mvpart(data.matrix(spider[,1:12])~herbs+reft+moss+sand+twigs+water,spider)       # defaults         
mvpart(data.matrix(spider[,1:12])~herbs+reft+moss+sand+twigs+water,spider,xv="p")  # pick the tree size
# pick cv size and do PCA
fit <- mvpart(data.matrix(spider[,1:12])~herbs+reft+moss+sand+twigs+water,spider,xv="1se",pca=TRUE)  
rpart.pca(fit,interact=TRUE,wgt.ave=TRUE) # interactive PCA plot of saved multivariate tree 
}
\keyword{tree}

\eof
\name{na.rpart}
\alias{na.rpart}
\title{
  Handles Missing Values in an Rpart Object 
}
\usage{
na.rpart(x)
}
\description{
  Handles missing values in an \code{rpart} object.
}
\arguments{
\item{x}{
  a model frame.
}}
\details{
  Internal function that handles missing values when calling the
  function \code{rpart}.
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{node.match}
\alias{node.match}
\title{
  Node.match
}
\description{
  Internal function for Rpart
}

\details{
  \code{node.match} is to be used only internally.
}
\keyword{internal}


\eof
\name{path.rpart}
\alias{path.rpart}
\title{
  Follow Paths to Selected Nodes of an Rpart Object
}
\description{
  Returns a names list where each element contains the splits on the
  path from the root to the selected nodes.
}
\usage{
path.rpart(tree, nodes, pretty=0, print.it=TRUE)
}
\arguments{
\item{tree}{
  fitted model object of class \code{rpart}.  This is assumed to be the
  result of some function that produces an object with the same named
  components as that returned by the \code{rpart} function.
}
\item{nodes}{
  an integer vector containing indices (node numbers) of all nodes for
  which paths are desired.  If missing, user selects nodes as described
  below. 
}
\item{pretty}{
  an integer denoting the extent to which factor levels in split labels
  will be abbreviated.  A value of (0) signifies no abbreviation.  A
  \code{NULL}, the default, signifies using elements of letters to represent
  the different factor levels.
}
\item{print.it}{
  Logical. Denotes whether paths will be printed out as
  nodes are interactively selected.   Irrelevant if \code{nodes}
  argument is supplied.
}}
\value{
  A named (by node) list, each element of which contains all
  the  splits  on the path from the root to the specified or
  selected nodes.
}
\section{Graphical Interaction}{
  A dendrogram of the \code{rpart} object is expected to be visible 
  on the graphics  device, and a graphics input device (eg a mouse)
  is required.  Clicking (the selection button)  on  a  node
  selects  that  node.   This  process  may  be repeated any
  number of times.  Clicking the exit button will  stop  the
  selection process and return the list of paths.
}
\details{
  The function has a required argument as an \code{rpart} object  and
  a list of nodes as optional arguments.  Omitting a list of
  nodes will cause the function to  wait  for  the  user  to
  select  nodes  from the dendogram.  It will return a list,
  with one component for each node  specified  or  selected.
  The  component  contains the sequence of splits leading to
  that node.  In the graphical  interation,  the  individual
  paths are printed out as nodes are selected.
}
\references{
  This function was modified from \code{path.tree} in S. 
}
\seealso{
  \code{\link{rpart}}
}
\examples{
data(kyphosis)
fit <- rpart(Kyphosis ~ Age + Number + Start, data=kyphosis)
summary(fit)
path.rpart(fit, node=c(11, 22))
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{plot.rpart}
\alias{plot.rpart}
\title{
Plot an Rpart Object
}
\description{
Plots an rpart object on the current graphics device.
}
\usage{
\method{plot}{rpart}(x, uniform=FALSE, branch=1, compress=FALSE, nspace,
     margin=0, minbranch=.3, bar, ms.fudge = TRUE,\dots)
}
\arguments{
\item{x}{
  a fitted object of class \code{rpart}, containing a classification,
  regression, or rate tree.
}
\item{uniform}{
if \code{TRUE}, uniform vertical spacing of the nodes is used; this may be
less cluttered when fitting a large plot onto a page.
The default is to use a non-uniform spacing proportional to the 
error in the fit.
}
\item{branch}{
controls the shape of the branches from parent to child node.
Any number from 0 to 1 is allowed.  A value of 1 gives square
shouldered branches, a value of 0 give V shaped branches, 
with other values being intermediate.
}
\item{compress}{
If \code{FALSE}, the leaf nodes will be at the horzontal plot coordinates of
\code{1:nleaves}.  
If \code{TRUE}, the routine attempts a more compact arrangement of
the tree.
The compaction algorithm assumes \code{uniform=TRUE}; surprisingly, the result
is usually an improvement even when that is not the case.
}
\item{nspace}{
the amount of extra space between a node with children and
a leaf, as compared to the minimal space between leaves.  
Applies to compressed trees only.  The default is the value of
\code{branch}.
}
\item{margin}{
an extra percentage of white space to leave around the borders of the tree.
(Long labels sometimes get cut off by the default computation).
}
\item{minbranch}{
set the minimum length for a branch to \code{minbranch} times the average
branch length.  This parameter is ignored if \code{uniform=TRUE}.
Sometimes a split will give very little improvement, or even (in
the classification case) no improvement at all.  
A tree with branch lengths strictly proportional to improvement
leaves no room to squeeze in node labels.
}
\item{bar}{
 length of bar at root (default = 0.03) -- used instead of char "|"
}
\item{ms.fudge}{
If \code{TRUE} adjust "legs" of plots to avoid MicroSoft metafile stuff-ups!!
}
\item{\dots}{
  arguments to be passed to or from other methods.
}}
\value{
the coordinates of the nodes are returned as a list, with
components \code{x} and \code{y}.
}
\section{Side Effects}{
an unlabeled plot is produced on the current graphics device.
}
\details{
This function is a method for the generic function \code{plot}, for objects
of class \code{rpart}.
The y-coordinate of the top node of the tree will always be 1.
}
\seealso{
\code{\link{rpart}}, \code{\link{text.rpart}}
}
\examples{
data(car.test.frame)
fit <- rpart(Price ~ Mileage + Type + Country, car.test.frame)
plot(fit, compress=TRUE)
text(fit, use.n=TRUE)
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{plotcp}
\alias{plotcp}
\title{
  Plot a Complexity Parameter Table for an Rpart Fit 
}
\description{
Gives a visual representation of the cross-validation results in an 
\code{rpart} object. 
}
\usage{
plotcp(x, xvse = 1, minline = TRUE, upper = c("size", 
    "splits", "none"), tab, resub.err = TRUE, adj.df = FALSE, ...) 
}
\synopsis{
plotcp(x, xvse = 1, minline = TRUE, lty = 3, col = 1, upper = c("size", 
    "splits", "none"), tab, resub.err = TRUE, adj.df = FALSE, ...) 
}
\arguments{
\item{x}{
an object of class \code{rpart} 
}
\item{xvse}{
multiplier for xvse * SE above the minimum of the curve. 
}
\item{minline}{
whether a horizontal line is drawn 1SE above the minimum of the curve. 
}
\item{upper}{
what is plotted on the top axis: the size of the tree (the number of
leaves), the number of splits or nothing. 
}
\item{tab}{
used for multiple cross-validation.
}
\item{resub.err}{
use resubstitution error for calculations of SEs.
}
\item{adj.df}{
adjust df of resubstitution error estimate for calculations of SEs.
}
\item{\dots}{
additional plotting parameters 
}
}
\value{
None. 
}
\section{Side Effects}{
A plot is produced on the current graphical device. 
}
\details{
The set of possible cost-complexity prunings of a tree from a nested
set. For the geometric means of the intervals of values of \code{cp} for which
a pruning is optimal, a cross-validation has (usually) been done in
the initial construction by \code{\link{rpart}}. The \code{cptable} in the fit contains
the mean and standard deviation of the errors in the cross-validated
prediction against each of the geometric means, and these are plotted
by this function. A good choice of \code{cp} for pruning is often the
leftmost value for which the mean lies below the horizontal line.
}
\seealso{
\code{\link{rpart}},  \code{\link{printcp}},  \code{\link{rpart.object}}   
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{post.rpart}
\alias{post.rpart}
\alias{post}
\title{
  PostScript Presentation Plot of an Rpart Object 
}
\description{
Generates a PostScript presentation plot of an \code{rpart} object. 
}
\usage{
\method{post}{rpart}(tree, title., 
     filename = paste(deparse(substitute(tree)), ".ps", sep = ""), 
     digits = getOption("digits") - 3, pretty = TRUE,
     use.n = TRUE, horizontal = TRUE, \dots)
}
\arguments{
\item{tree}{
fitted model object of class \code{rpart}.  This is assumed to be the result 
of some function that produces an object with the same named 
components as that returned by the \code{rpart} function. 
}
\item{title.}{
a title which appears at the top of the plot.  By default, the 
name of the \code{rpart} endpoint is printed out. 
}
\item{filename}{
ASCII file to contain the output.  By default, the name of the file is 
the name of the object given by \code{rpart} (with the suffix \code{.ps} added). If 
\code{filename = ""}, the plot appears on the current graphical device. 
}
\item{digits}{
number of significant digits to include in numerical data. 
}
\item{pretty}{
an integer denoting the extent to which factor levels will be 
abbreviated in the character strings defining the splits; 
(0) signifies no abbreviation of levels.  A \code{NULL} signifies using 
elements of letters to represent the different factor levels.  The 
default (\code{TRUE}) indicates the maximum possible abbreviation. 
}
\item{use.n}{
Logical.  If \code{TRUE} (default), adds to label 
(\#events level1/ \#events level2/etc. for method \code{class}, \code{n} for 
method \code{anova}, and \#events/n for methods \code{poisson} and \code{exp}).
}
\item{horizontal}{
Logical.  If \code{TRUE} (default), plot is horizontal. If \code{FALSE}, plot 
appears as landscape. 
}
\item{\dots}{
other arguments to the \code{postscript} function. 
}
}
\section{Side Effects}{
a plot of \code{rpart} is created using the \code{postscript} driver, or
the current device if \code{filename = ""}.
}
\details{
The plot created uses the functions \code{plot.rpart} and \code{text.rpart} (with 
the \code{fancy} option).  The settings were chosen because they looked 
good to us, but other options may be better, depending on the \code{rpart} 
object.   
Users are encouraged to write their own function containing favorite 
options. 
}
\seealso{
\code{\link{plot.rpart}},  \code{\link{rpart}},  \code{\link{text.rpart}},  \code{\link{abbreviate}}   
}
\examples{
data(car.test.frame)
z.auto <- rpart(Mileage ~ Weight, car.test.frame)
post(z.auto, file = "")   # display tree on active device
   # now construct postscript version on file "pretty.ps"
   # with no title
post(z.auto, file = "pretty.ps", title = " ")
z.hp <- rpart(Mileage ~ Weight + HP, car.test.frame)
post(z.hp)
}
\keyword{tree}

\eof
\name{predict.rpart}
\alias{predict.rpart}
\alias{pred.rpart}
\title{
  Predictions from a Fitted Rpart Object 
}
\description{
  Returns a vector of predicted responses from a fitted \code{rpart} object. 
}
\usage{
\method{predict}{rpart}(object, newdata=list(),
       type=c("vector", "prob", "class", "matrix"), ...)
}
\arguments{
  \item{object}{
    fitted model object of class \code{rpart}.  This is assumed to be
    the result of some function that produces an object with the same named 
    components as that returned by the \code{rpart} function. 
  }
  \item{newdata}{
    data frame containing the values at which predictions are required. 
    The predictors referred to in the right side of
    \code{formula(object)} must be present by name in \code{newdata}.
    If missing, the fitted values are returned. 
  }
  \item{type}{
    character string denoting the type of predicted value returned.  If
    the \code{rpart} object is a classification tree, then the default is to
    return \code{prob} predictions, a matrix whose columns are the
    probability of the first, second, etc. class.  (This agrees with the
    default behavior of \code{\link[tree]{tree}}).  Otherwise, a vector
    result is returned.
  }
  \item{\dots}{further arguments passed to or from other methods.}
}
\value{
  A new object is obtained by
  dropping \code{newdata} down the object.  For factor predictors, if an
  observation contains a level not used to grow the tree, it is left at
  the deepest possible node and \code{frame$yval} at the node is the
  prediction.

  If \code{type="vector"}:\cr
  vector of predicted responses.
  For regression trees this is the mean response at the node, for Poisson
  trees it is the estimated response rate, and for classification trees
  it is the predicted class.
  
  If \code{type="prob"}:\cr
  (for a classification tree) a matrix of class probabilities.

  If \code{type="matrix"}:\cr
  a matrix of the full responses (\code{frame$yval2} if this exists,
  otherwise \code{frame$yval}).
  For regression trees, this is the mean response, for Poisson trees it
  is the response rate and the number of events at that node in the fitted
  tree, and for classification trees it is the concatonation of the
  predicted class, the class counts at that node in the fitted tree, and
  the class probabilities.

  If \code{type="class"}:\cr
  (for a classification tree) a factor of classifications based on the
  responses.
}
\details{
  This function is a method for the generic function predict for class
  \code{rpart}. It can be invoked by calling \code{predict} for an object
  of the appropriate class, or directly by calling \code{predict.rpart}
  regardless of the class of the object.
}
\seealso{
\code{\link{predict}},  \code{\link{rpart.object}}   
}
\examples{
data(car.test.frame)
z.auto <- rpart(Mileage ~ Weight, car.test.frame)
predict(z.auto)

data(kyphosis)
fit <- rpart(Kyphosis ~ Age + Number + Start, data=kyphosis)
predict(fit, type="prob")   # class probabilities (default)
predict(fit, type="vector") # level numbers
predict(fit, type="class")  # factor
predict(fit, type="matrix") # level number, class frequencies, probabilities

data(iris)
sub <- c(sample(1:50, 25), sample(51:100, 25), sample(101:150, 25))
fit <- rpart(Species ~ ., data=iris, subset=sub)
fit
table(predict(fit, iris[-sub,], type="class"), iris[-sub, "Species"])
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{print.rpart}
\alias{print.rpart}
\title{
  Print an Rpart Object 
}
\description{
This function prints an \code{rpart} object.  It is a method for the generic 
function \code{print} of class \code{rpart}. 
}
\usage{
\method{print}{rpart}(x, minlength=0, spaces=2, cp, digits= getOption("digits"), \dots)
}
\arguments{
\item{x}{
fitted model object of class \code{rpart}.  This is assumed to be the result 
of some function that produces an object with the same named 
components as that returned by the \code{rpart} function. 
}
\item{minlength}{
Controls the abbreviation of labels: see \code{\link{labels.rpart}}.
}
\item{spaces}{
the number of spaces to indent nodes of increasing depth. 
}
\item{digits}{
the number of digits of numbers to print. 
}
\item{cp}{
  prune all nodes with a complexity less than \code{cp} from the
  printout. Ignored if unspecified.
}
\item{\dots}{
  arguments to be passed to or from other methods.
}}
\section{Side Effects}{
  A semi-graphical layout of the contents of \code{x$frame} is
  printed.  Indentation is used to convey the tree topology.
  Information for each node includes the node number, split, size,
  deviance, and fitted value.  For the \code{"class"} method, the
  class probabilties are also printed. 
}
\details{
  This function is a method for the generic function \code{print} for class 
  \code{"rpart"}.  It can be invoked by calling print for an object of the 
  appropriate class, or directly by calling \code{print.rpart} regardless of 
  the class of the object. 
}
\seealso{
  \code{\link{print}},  \code{\link{rpart.object}},
  \code{\link{summary.rpart}},  \code{\link{printcp}}   
}
\examples{
data(car.test.frame)
z.auto <- rpart(Mileage ~ Weight, car.test.frame)
z.auto
\dontrun{node), split, n, deviance, yval
      * denotes terminal node

 1) root 60 1354.58300 24.58333  
   2) Weight>=2567.5 45  361.20000 22.46667  
     4) Weight>=3087.5 22   61.31818 20.40909 *
     5) Weight<3087.5 23  117.65220 24.43478  
      10) Weight>=2747.5 15   60.40000 23.80000 *
      11) Weight<2747.5 8   39.87500 25.62500 *
   3) Weight<2567.5 15  186.93330 30.93333 *
}}
\keyword{tree}
% docclass is function

\eof
\name{printcp}
\alias{printcp}
\title{
  Displays CP table for Fitted Rpart Object 
}
\description{
  Displays the \code{cp} table for fitted \code{rpart} object.
}
\usage{
printcp(x, digits=getOption("digits") - 2)
}
\arguments{
\item{x}{
fitted model object of class \code{rpart}.  This is assumed to be the result 
of some function that produces an object with the same named 
components as that returned by the \code{rpart} function. 
}
\item{digits}{
  the number of digits of numbers to print.
}}
\details{
Prints a table of optimal prunings based on a complexity parameter. 
}
\seealso{
\code{\link{summary.rpart}},  \code{\link{rpart.object}}   
}
\examples{
data(car.test.frame)
z.auto <- rpart(Mileage ~ Weight, car.test.frame)
printcp(z.auto)
\dontrun{
Regression tree:
rpart(formula = Mileage ~ Weight, data = car.test.frame)

Variables actually used in tree construction:
[1] Weight

Root node error: 1354.6/60 = 22.576

        CP nsplit rel error  xerror     xstd 
1 0.595349      0   1.00000 1.03436 0.178526
2 0.134528      1   0.40465 0.60508 0.105217
3 0.012828      2   0.27012 0.45153 0.083330
4 0.010000      3   0.25729 0.44826 0.076998
}}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{prune.rpart}
\alias{prune.rpart}
\alias{prune}
\title{
  Cost-complexity Pruning of an Rpart Object 
}
\description{
Determines a nested sequence of subtrees of the supplied \code{rpart} object 
by recursively \code{snipping} off the least important splits, based on the 
complexity parameter (\code{cp}). 
}
\usage{
\method{prune}{rpart}(tree, cp, ...)
}
\arguments{
\item{tree}{
fitted model object of class \code{rpart}.  This is assumed to be the result 
of some function that produces an object with the same named 
components as that returned by the \code{rpart} function. 
}
\item{cp}{
  Complexity parameter to which the \code{rpart} object will be trimmed.
}
\item{\dots}{further arguments passed to or from other methods.}
}
\value{
A new \code{rpart} object that is trimmed to the value \code{cp}. 
}
\seealso{
\code{\link{rpart}} 
}
\examples{
data(car.test.frame)
z.auto <- rpart(Mileage ~ Weight, car.test.frame)
zp <- prune(z.auto, cp=0.1)
plot(zp) #plot smaller rpart object
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{residuals.rpart}
\alias{residuals.rpart}
\title{
  Residuals From a Fitted Rpart Object 
}
\usage{
\method{residuals}{rpart}(object, type = c("usual", "pearson", "deviance"), ...)
}
\description{
  Method for \code{residuals} for an \code{rpart} object.
}
\arguments{
\item{object}{
  fitted model object of class \code{"rpart"}.
}
\item{type}{
  Indicates the type of residual desired.

  For regression or \code{anova} trees all three residual
  definitions reduce to \code{y - fitted}.  This is the residual returned for
  \code{user} method trees as well.

  For classification trees the \code{usual} residuals
  are the missclassification losses L(actual, predicted) where L is the
  loss matrix.  With default losses this residual is
  0/1 for correct/incorrect classification.
  The \code{pearson} residual is 
  (1-fitted)/sqrt(fitted(1-fitted)) and the \code{deviance} residual is 
  sqrt(minus twice logarithm of fitted).

  For \code{poisson} and \code{exp}
  (or survival) trees, the \code{usual} residual
  is the observed - expected number of events.
  The \code{pearson} and \code{deviance} residuals are as defined in
  McCullagh and Nelder.
}
\item{\dots}{further arguments passed to or from other methods.}

}
\value{
vector of residuals of type \code{type} from a fitted \code{rpart} object. 
}
\references{
  McCullagh P. and Nelder, J. A. (1989)
  \emph{Generalized Linear Models}.
  London: Chapman and Hall.
}
\examples{
data(solder)
fit <- rpart(skips ~ Opening + Solder + Mask + PadType + Panel,
       data=solder, method='anova')
summary(residuals(fit))
plot(predict(fit),residuals(fit))
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{rpart}
\alias{rpart}
\alias{rpartcallback}
\title{
Recursive Partitioning and Regression Trees
}
\description{
Fit a \code{rpart} model 
}
\usage{
rpart(formula, data=NULL, weights, subset, na.action=na.rpart, method,
      model=FALSE, x=FALSE, y=TRUE, parms, control, cost, \dots)
}
\arguments{
\item{formula}{
a formula, as in the \code{lm} function. 
}
\item{data}{
an optional data frame in which to interpret the variables named in the 
formula 
}
\item{weights}{
optional case weights.
}
\item{subset}{
optional expression saying that only a subset of the rows of the data 
should be used in the fit. 
}
\item{na.action}{
The default action deletes all observations for which \code{y} is missing, 
but keeps those in which one or more predictors are missing. 
}
\item{method}{
one of \code{"anova"}, \code{"poisson"}, \code{"class"}, \code{"mrt"},
\code{"dist"}, or \code{"exp"}. 
If \code{method} is missing then the routine tries to make an intellegent guess. 
If \code{y} is a survival object, then \code{method="exp"} is assumed, 
if \code{y} is a matrix then \code{method="mrt"} is assumed, 
if \code{y} is a factor then \code{method="class"} is assumed, otherwise \code{method="anova"} 
is assumed.  It is wisest to specifiy the method directly, especially as 
more criteria are added to the function.

For method=\code{"dist"} the response must be a square symmetric distance matrix; e.g. 
returned by \code{\link[mvpart]{gdist}} or \code{\link[mvpart]{xdiss}}. Weights and 
cross-validation are currently not implemented for method=\code{"dist"}. 


Alternatively, \code{method} can be a list of functions named
\code{init}, \code{split} and \code{eval}.
}
\item{model}{
keep a copy of the model frame in the result. 
If the input value for \code{model} is a model frame (likely from an earlier 
call to the \code{rpart} function), then this frame is used rather than constructing 
new data. 
}
\item{x}{
keep a copy of the \code{x} matrix in the result. 
}
\item{y}{
keep a copy of the dependent variable in the result. 
}
\item{parms}{
optional parameters for the splitting function.
Anova splitting has no parameters.
Poisson splitting has a single parameter, the coefficient of variation of
the prior distribution on the rates.  The default value is 1.
Exponential splitting has the same parameter as Poisson.
For classification splitting, the list can contain any of:
the vector of prior probabilities (component \code{prior}), the loss matrix
(component \code{loss}) or the splitting index (component \code{split}).  The
priors must be positive and sum to 1.  The loss matrix must have zeros
on the diagnoal and positive off-diagonal elements.  The splitting
index can be \code{gini} or \code{information}.  The default priors are 
proportional to the data counts, the losses default to 1, 
and the split defaults to \code{gini}.
}
\item{control}{
options that control details of the \code{rpart} algorithm. 
}
\item{cost}{
a vector of non-negative costs, one for each variable in the
model. Defaults to one for all variables.  These are scalings to be
applied when considering splits, so the improvement on splitting on a
variable is divided by its cost in deciding which split to choose.
}
\item{\dots}{
arguments to \code{rpart.control} may also be specified in the call to
\code{rpart}.  They are checked against the list of valid arguments.
}
}
\value{
an object of class \code{rpart}, a superset of class \code{tree}. 
}
\details{
This differs from the \code{tree} function mainly in its handling of surrogate
variables.  In most details it follows Breiman et. al. quite closely.
}
\references{
Breiman, Friedman, Olshen, and Stone. (1984) 
\emph{Classification and Regression Trees.}
Wadsworth. 

De'ath G. (2002)  
Multivariate Regression Trees : A New Technique for Constrained Classification Analysis.
Ecology 83(4):1103-1117.
}
\seealso{
  \code{\link{rpart.control}}, \code{\link{rpart.object}},
  \code{\link{summary.rpart}}, \code{\link{print.rpart}}
}
\examples{

data(car.test.frame)
z.auto <- rpart(Mileage ~ Weight, car.test.frame)
summary(z.auto)
plot(z.auto); text(z.auto)

data(spider)
fit1 <- rpart(data.matrix(spider[,1:12])~water+twigs+reft+herbs+moss+sand,spider,method="mrt")
fit2 <- rpart(gdist(spider[,1:12],meth="bray",full=TRUE,sq=TRUE)~water+twigs+reft+herbs+moss+sand,spider,method="dist")
par(mfrow=c(1,2))
plot(fit1); text(fit1)
plot(fit2); text(fit2)

}
\keyword{tree}

\eof
\name{rpart.anova}
\alias{rpart.anova}
\title{
  Set up for `anova' Method for an Rpart Model
}
\description{
  Set up for \code{anova} method for an \code{rpart} model.
}
\usage{
rpart.anova(y, offset, parms, wt)
}
\arguments{
  \item{y}{the responses.}
  \item{offset}{an offset, or \code{NULL}.}
  \item{parms}{a list of parameters, usually empty.}
  \item{wt}{case weights.}
}
\value{
  Returns a list consisting of
  \item{y}{(subtracting \code{offset} if necessary),}
  \item{parms}{as input,}
  \item{numresp}{the number of responses, here \code{1},}
  \item{summary}{a function to be invoked by \code{\link{summary.rpart}},}
  \item{text}{a function to be invoked by \code{\link{text.rpart}}.}
}
\details{
  \code{rpart.anova} is to be used only by the function \code{rpart}.
}
\keyword{internal}

\eof
\name{rpart.branch}
\alias{rpart.branch}
\title{
  Rpart.branch
}
\description{
  Internal function for Rpart
}

\details{
  \code{rpart.branch} is to be used only internally.
}
\keyword{internal}


\eof
\name{rpart.class}
\alias{rpart.class}
\title{
  Set up for `class' Method for an Rpart Model
}
\description{
  Set up for the \code{class} method for an \code{rpart} model.
}
\usage{
rpart.class(y, offset, parms, wt)
}
\arguments{
  \item{y}{the responses.}
  \item{offset}{\code{NULL}: anything else is an error.}
  \item{parms}{a named list of parameters.}
  \item{wt}{case weights.}
}
\value{
  Returns a list consisting of
  \item{y}{\code{y} as factor codes,}
  \item{parms}{a named list of parameters.  This will have components
    \code{prior}, \code{loss} and \code{split} (and more if supplied).}
  \item{numresp}{the number of responses (one plus the number of classes).}
  \item{counts}{a vector of counts for each class.}
  \item{ylevels}{the response levels corresponding to the codes given in
    \code{y}.}
  \item{summary}{a function to be invoked by \code{\link{summary.rpart}},}
  \item{text}{a function to be invoked by \code{\link{text.rpart}}.}
}
\details{
  \code{rpart.class} is to be used only by the function \code{rpart}. It
  validates the input parameter list: if that is missing or \code{NULL}
  default values are supplied.
}
\seealso{
\code{\link{rpart}} 
}
\keyword{internal}

\eof
\name{rpart.control}
\alias{rpart.control}
\title{
  Control for Rpart Models
}
\description{
Various parameters that control aspects of the \code{rpart} fit. 
}
\usage{
rpart.control(minsplit=5, minbucket=round(minsplit/3), cp=0.01, 
              maxcompete=4, maxsurrogate=5, usesurrogate=2, xval=10,
	      surrogatestyle=0, maxdepth=30, \dots)
}
\arguments{
\item{minsplit}{
the minimum number of observations that must exist in a node, in order for 
a split to be attempted. 
}
\item{minbucket}{
  the minimum number of observations in any terminal \code{<leaf>} node.
  If only one of \code{minbucket} or \code{minsplit} is specified,
  the code either sets \code{minsplit} to \code{minbucket*3}
  or \code{minbucket} to \code{minsplit/3}, as appropriate.
}
\item{cp}{
  complexity parameter.  Any split that does not decrease the overall
  lack of fit by a factor of \code{cp} is not attempted.  For instance,
  with \code{anova} splitting, this means that the overall Rsquare must
  increase by \code{cp} at each step. The main role of this parameter
  is to save computing time by pruning off splits that are obviously
  not worthwhile. Essentially,the user informs the program that any
  split which does not improve the fit by \code{cp} will likely be
  pruned off by cross-validation, and that hence the program need
  not pursue it.
}
\item{maxcompete}{
  the number of competitor splits retained in the output.  It is useful to
  know not just which split was chosen, but which variable came in second,
  third, etc.
}
\item{maxsurrogate}{
  the number of surrogate splits retained in the output.  If this is set to
  zero the compute time will be shortened, since approximately half of the
  computational time (other than setup) is used in the search for surrogate
  splits.
}
\item{usesurrogate}{
  how to use surrogates in the splitting process.  0= display only; an
  observation with a missing value for the primary split rule is not sent
  further down the tree.  1= use surrogates, in order, to split subjects
  missing the primary variable; if all surrogates are missing the observation
  is not split.  2= if all surrogates are missing, then send the observation
  in the majority direction.  A value of 0 corresponds to the action of
  \code{tree}, and 2 to the recommendations of Breiman, et.al.
}
\item{xval}{
number of cross-validations 
}
\item{surrogatestyle}{
  controls the selection of a best surrogate.
  If set to 0 (default) the program uses the total number of correct
  classification for a potential surrogate variable,
  if set to 1 it uses the percent correct, calculated over the non-missing
  values of the surrogate.
  The first option more severely penalizes covariates with a large number of
  missing values.
}
\item{maxdepth}{
  Set the maximum depth of any node of the final tree, with the root
  node counted as depth 0 (past 30 \code{rpart} will give nonsense results on
  32-bit machines).
}
\item{\dots}{
  mop up other arguments.
}
}
\value{
  a list containing the options.
}
\seealso{
\code{\link{rpart}}
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{rpart.dist}
\alias{rpart.dist}
\title{
  Set up for `dist' Method for an Rpart Model
}
\description{
  Set up for \code{dist} method for an \code{rpart} model.
}
\usage{
rpart.dist(y, offset, parms, wt)
}
\arguments{
  \item{y}{the responses.}
  \item{offset}{an offset, or \code{NULL}.}
  \item{parms}{a list of parameters, usually empty.}
  \item{wt}{case weights -- ignored.}
}
\value{
  Returns a list consisting of
  \item{y}{(subtracting \code{offset} if necessary),}
  \item{parms}{as input,}
  \item{numresp}{the number of responses,}
  \item{summary}{a function to be invoked by \code{\link{summary.rpart}},}
  \item{text}{a function to be invoked by \code{\link{text.rpart}}.}
}
\details{
  \code{rpart.dist} is to be used only by the function \code{rpart}.
}
\keyword{internal}


\eof
\name{rpart.exp}
\alias{rpart.exp}
\title{
  Set up for `exp' Method for an Rpart Model
}
\description{
  Set up for the \code{exp} method for an \code{rpart} model.
}
\usage{
rpart.exp(y, offset, parms, wt)
}
\arguments{
  \item{y}{the responses, a vector or a two-column matrix.}
  \item{offset}{an offset, or \code{NULL}.}
  \item{parms}{a list of parameters.}
  \item{wt}{case weights.}
}
\value{
  Returns a list consisting of
  \item{y}{a matrix giving the observation times and number of events,}
  \item{parms}{a named list of parameters, with components \code{shrink}
    and \code{method} (1 for \code{"deviance"}, 2 for \code{"sqrt"}),}
  \item{numresp}{the number of responses, here \code{2},}
  \item{numy}{the number of columns in \code{y}, here \code{2},}
  \item{summary}{a function to be invoked by \code{\link{summary.rpart}},}
  \item{text}{a function to be invoked by \code{\link{text.rpart}}.}
}
\details{
  \code{rpart.exp} is to be used only by the function \code{rpart}.  It
  transforms the data to look like a unit-rate Poisson process so that
  the \code{rpart.exp} method can be used.
}
\keyword{internal}

\eof
\name{rpart.matrix}
\alias{rpart.matrix}
\title{
  Creates a Model Matrix from a Call to Rpart
}
\description{
  Creates a model matrix from a call to \code{rpart}. 
}
\usage{
rpart.matrix(frame)
}
\arguments{
\item{frame}{
  model frame (from call to \code{rpart})
}}
\value{
  Returns a matrix from the frame of class \code{matrix}.  Used internally by
  the function \code{rpart}.
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{rpart.mrt}
\alias{rpart.mrt}
\title{
  Set up for `mrt' Method for an Rpart Model
}
\description{
  Set up for \code{mrt} method for an \code{rpart} model.
}
\usage{
rpart.mrt(y, offset, parms, wt)
}
\arguments{
  \item{y}{the responses.}
  \item{offset}{an offset, or \code{NULL}.}
  \item{parms}{a list of parameters, usually empty.}
  \item{wt}{case weights.}
}
\value{
  Returns a list consisting of
  \item{y}{(subtracting \code{offset} if necessary),}
  \item{parms}{as input,}
  \item{numresp}{the number of responses,}
  \item{summary}{a function to be invoked by \code{\link{summary.rpart}},}
  \item{text}{a function to be invoked by \code{\link{text.rpart}}.}
  \item{bar}{a function to be invoked by \code{\link{text.rpart}}.}
}
\details{
  \code{rpart.mrt} is to be used only by the function \code{rpart}.
}
\keyword{internal}

\eof
\name{rpart.object}
\alias{rpart.object}
\title{
  Recursive Partitioning and Regression Trees Object 
}
\description{
These are objects representing fitted \code{rpart} trees. 
}
\section{Structure}{
The following components must be included in a legitimate \code{rpart} object. 
Of these, only the \code{where} component has the same length as  
the data used to fit the \code{rpart} object. 
}
\value{

\item{frame}{
data frame with one row for each node in the tree.
The \code{row.names} of \code{frame} contain the (unique) node numbers that
follow a binary ordering indexed by node depth.
Elements of \code{frame} include \code{var},
the variable used in the split at each node
(leaf nodes are denoted by the string \code{<leaf>}), \code{n}, the size of each node,
\code{wt}, the sum of case weights for the node,
\code{dev}, the deviance of each node,
\code{yval}, the fitted value of the response at each node,
and \code{splits}, a two column matrix of left and right split labels
for each node.
All of these are the same as for an \code{rpart} object.

Extra response information is in \code{yval2}, which contains the number
of events at the node (poisson), or a matrix containing the fitted
class, the class counts for each node and the class probabilities
(classification).  Also included in the frame are \code{complexity}, the
complexity parameter at which this split will collapse, \code{ncompete},
the number of competitor splits retained, and \code{nsurrogate}, the
number of surrogate splits retained.
}
\item{where}{
vector, the same length as the number of observations in the root node, 
containing the row number of \code{frame} corresponding to the leaf node 
that each observation falls into. 
}
\item{splits}{
a matrix describing the splits.  The row label is the name of the split
variable, and columns are \code{count}, the number of observations sent left
or right by the split (for competitor splits this is the number that
would have been sent left or right had this split been used, for surrogate
splits it is the number missing the primary split variable which were decided
using this surrogate), \code{ncat}, the number of categories or levels for the
variable (\code{+/-1} for a continuous variable), \code{improve}, which is the improvement
in deviance given by this split, or, for surrogates, the concordance of the
surrogate with the primary, and \code{split}, the numeric split point.  
The last column \code{adj} gives the adjusted concordance for surrogate splits.
For
a factor, the \code{split} column contains the row number of the csplit matrix.
For a continuous variable, the sign of \code{ncat} determines whether the
subset \code{x < cutpoint} or \code{x > cutpoint} is sent to the left.
}
\item{csplit}{
this will be present only if one of the split variables is a factor. There
is one row for each such split, and column \code{i = -1} if this level of the
factor goes to the left, \code{+1} if it goes to the right, and 0 if that level
is not present at this node of the tree.
For an ordered categorical variable all levels are marked as \code{R/L}, 
including levels that are not present.
}
\item{method}{
the method used to grow the tree. 
}
\item{cptable}{
the table of optimal prunings based on a complexity parameter. 
}
\item{terms}{
an object of mode \code{expression} and class \code{term} summarizing the formula. 
Used by various methods, but typically not of direct relevance to users. 
}
\item{call}{
an image of the call that produced the object, but with the arguments 
all named and with the actual formula included as the formula argument. 
To re-evaluate the call, say \code{update(tree)}. 

Optional components include the matrix of predictors (\code{x}) and the 
response variable (\code{y}) used to construct the \code{rpart} object. 
}
}
\seealso{
\code{\link{rpart}}.
}
\keyword{tree}
\keyword{methods}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{rpart.pca}
\alias{rpart.pca}
\title{
Principle Components Plot of a Multivariate Rpart Object
}
\description{
Plots a PCA of the rpart object on the current graphics device.
}
\usage{
\rpart.pca(tree, pts = TRUE, plt.allx = TRUE, speclab = TRUE,
    specvecs = TRUE, wgt.ave = FALSE, add.tree = TRUE,  
    cv1 = 1, cv2 = 2, interact = FALSE, \dots) 
}
\arguments{
\item{tree}{
A fitted object of class \code{rpart} containing a multivariate 
regression tree.
}
\item{pts}{
If \code{TRUE}, large points representing the leaf means are plotted.
}
\item{plt.allx}{
If \code{TRUE}, small points representing individual cases are plotted.
}
\item{speclab}{
If \code{TRUE} the labels of the response variables are plotted.
}
\item{specvecs}{
If \code{TRUE} the vectors of the response variables are plotted provided
\code{wgt.ave} is \code{FALSE} .
}
\item{wgt.ave}{
If \code{TRUE} use weighted averages of responses not vectors.
}
\item{add.tree}{
If \code{TRUE} add the tree structure to the plot.
}
\item{cv1, cv2}{
Defines which principal components to plot -- but see \code{interact} .
}
\item{interact}{
If \code{TRUE} the plot can be viewed in dimensions by left-clicking to 
top-left, bottom-right or bottom-left (reset).
}
\item{\dots}{
  arguments to be passed to or from other methods.
}}
\value{
NULL
}
\section{Side Effects}{
A PCA biplot plot is produced on the current graphics device.
}
\details{
This function plots a PCA biplot of the group means (leaves) of
 multivariate regresssion objects of class \code{rpart}.
The responses and group means and indivdual cases can be shown on the plot.
If responses are positive (eg species-environment data) weighted averages of 
responses can be plotted.

}
\seealso{
\code{\link{rpart}}, \code{\link{text.rpart}}
}
\examples{
data(spider)
fit<-mvpart(data.matrix(spider[,1:12])~herbs+reft+moss+sand+twigs+water,spider)
rpart.pca(fit)
rpart.pca(fit,wgt.ave=TRUE,interact=TRUE)
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{rpart.poisson}
\alias{rpart.poisson}
\title{
  Set up for `poisson' Method for an Rpart Model 
}
\description{
  Set up for \code{poisson} method for an \code{rpart} model. 
}
\usage{
rpart.poisson(y, offset, parms, wt)
}
\arguments{
  \item{y}{the responses, a vector or a two-column matrix.  If a matrix
    the first column is the observation times and the second is the counts.}
  \item{offset}{an offset, or \code{NULL}.  The offset is interpreted as
  a log observation time.}
  \item{parms}{a list of parameters.}
  \item{wt}{case weights.}
}
\value{
  Returns a list consisting of
  \item{y}{a matrix giving the observation times and number of events,}
  \item{parms}{a named list of parameters, with components \code{shrink}
    and \code{method} (1 for \code{"deviance"}, 2 for \code{"sqrt"}),}
  \item{numresp}{the number of responses, here \code{2},}
  \item{numy}{the number of columns in \code{y}, here \code{2},}
  \item{summary}{a function to be invoked by \code{\link{summary.rpart}},}
  \item{text}{a function to be invoked by \code{\link{text.rpart}}.}
}
\details{
  \code{rpart.poisson} is to be used only by the function \code{rpart}.
}
\keyword{internal}

\eof
\name{rpartco}
\alias{rpartco}
\title{
  Rpartco
}
\description{
  Internal function for Rpart
}

\details{
  \code{rpartco} is to be used only internally.
}
\keyword{internal}


\eof
\name{rpconvert}
\alias{rpconvert}
\title{
  Update an rpart object
}
\description{
Rpart objects changed (slightly) in their internal format in order to
accomdate the changes for user-written split functions.  This routine
updates an old object to the new format.
}
\usage{
rpconvert(x)
}
\arguments{
\item{x}{
an \code{rpart} object
}
}
\value{
an updated object
}
\seealso{
\code{rpart}
}
\keyword{tree}
% docclass is function

\eof
\name{rsq.rpart}
\alias{rsq.rpart}
\title{
  Plots the Approximate R-Square for the Different Splits 
}
\description{
  Produces 2 plots.  The first plots the r-square (apparent and
  apparent - from cross-validation) versus the number of splits.  
  The second plots the Relative Error(cross-validation) +/- 1-SE from
  cross-validation versus the number of splits.
}
\usage{
rsq.rpart(x)
}
\arguments{
\item{x}{
  fitted model object of class \code{rpart}.  This is assumed to be the result
  of some function that produces an object with the same named
  components as that returned by the \code{rpart} function.
}}
\section{Side Effects}{
  Two plots are produced.
}
\note{
  The labels are only appropriate for the \code{"anova"} method.
}
\examples{
data(car.test.frame)
z.auto <- rpart(Mileage ~ Weight, car.test.frame)
rsq.rpart(z.auto)
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{scaler}
\alias{scaler}
\title{Row and Column Scaling of a Data Matrix}
\description{
The function provides some popular (and effective) standardization
methods for community ecologists.
}

\usage{
scaler(x, col = NULL, row=NULL)
}
\arguments{
  \item{x}{ Data matrix.}
  \item{col}{ Character vector of column standardizations.}
  \item{row}{ Character vector of row standardizations.}
}
\details{
  The function offers following data matrix standardizations:
    \itemize{
    \item \code{mean1 }: scale to mean of 1.
    \item \code{max1 }: scale to maximum of 1.
    \item \code{ssq1 }: scale to sums of sqaures equal 1.
    \item \code{range01 }: scale range to 0-1.
    \item \code{zsc }: standardize to z-scores (mean=0, sd=1).
    \item \code{pa }: scale to presence/absence scale (0/1).
    \item \code{rank }: scale to rank order (1=lowest).
}


  Standardizations are performed first on columns then on rows.
  "pa" applies to the whole matrix and can be specied using row or col.  
}
\value{
  Returns the standardized matrix.
}
\author{Jari Oksanen -- modified Glenn De'ath (Dec 03)}
\note{Common transformations can be made with standard \R functions.}


\examples{
data(spider)
spid.data <- scaler(spider, col = "max", row="mean1")
}
\keyword{ multivariate}%-- one or more ...
\keyword{ manip }


\eof
\name{snip.rpart}
\alias{snip.rpart}
\title{
  Snip Subtrees of an Rpart Object 
}
\description{
  Creates a "snipped" rpart object, containing the nodes that remain
  after selected subtrees have been snipped off.  The user can snip
  nodes using the toss arguement, or interactively by clicking the mouse
  button on specified nodes within the graphics window.
}
\usage{
snip.rpart(x, toss)
}
\arguments{
\item{x}{
  fitted model object of class \code{rpart}.  This is assumed to be the result
  of some function that produces an object with the same named
  components as that returned by the \code{rpart} function.
}
\item{toss}{
  an integer vector containing indices (node numbers) of all subtrees to
  be snipped off.  If missing, user selects branches to snip off as
  described below.
}}
\value{
  a \code{rpart} object containing the nodes that remain after specified or
  selected subtrees have been snipped off.  
}
\details{
  A dendrogram of \code{rpart} is expected to be visible on the graphics
  device, and a graphics input device (e.g., a mouse) is required.  Clicking
  (the selection button) on a node displays the node number, sample
  size, response yvalue, and Error (dev). Clicking a second time on the
  same node snips that subtree off and visually erases the subtree.
  This process may be repeated an number of times.  Warnings result from
  selecting the root or leaf nodes.  Clicking the exit button will stop
  the snipping process and return the resulting \code{rpart} object.

  See the documentation for the specific graphics device for details on
  graphical input techniques.
}
\section{Warning}{
  Visually erasing the plot is done by over-plotting with the background
  colour.  This will do nothing if the background is transparent
  (often true for screen devices).
}
\seealso{
  \code{\link{plot.rpart}}
}
\examples{
## dataset not in R
\dontrun{
z.survey <- rpart(market.survey) #grow the rpart object
plot(z.survey) #plot the tree
z.survey2 <- snip.rpart(z.survey,toss=2) #trim subtree at node 2
plot(z.survey2) #plot new tree

# can also interactively select the node using the mouse in the
# graphics window
}}
\keyword{tree}

\eof
\name{snip.rpart.mouse}
\alias{snip.rpart.mouse}
\title{
  Snip.rpart.mouse
}
\description{
  Internal function for Rpart
}

\details{
  \code{snip.rpart.mouse} is to be used only internally.
}
\keyword{internal}


\eof
\name{solder}
\alias{solder}
\non_function{}
\title{Soldering of Components on Printed-Circuit Boards}
\description{
  The \code{solder} data frame has 720 rows and 6 columns, representing
  a balanced subset of a designed experiment varying 5 factors on the
  soldering of components on printed-circuit boards.
}
\usage{
data(solder)
}
\format{
This data frame contains the following columns:
\describe{
\item{\code{Opening}}{
a factor with levels
\code{L} 
\code{M} 
\code{S}
indicating the amount of clearance around the mounting pad.
}
\item{\code{Solder}}{
a factor with levels
\code{Thick} 
\code{Thin}
giving the thickness of the solder used.
}
\item{\code{Mask}}{
a factor with levels
\code{A1.5} 
\code{A3} 
\code{B3} 
\code{B6}
indicating the type and thickness of mask used.
}
\item{\code{PadType}}{
a factor with levels
\code{D4} 
\code{D6} 
\code{D7} 
\code{L4} 
\code{L6} 
\code{L7} 
\code{L8} 
\code{L9} 
\code{W4} 
\code{W9}
giving the size and geometry of the mounting pad.
}
\item{\code{Panel}}{
 \code{1:3} indicating the panel on a board being tested.
}
\item{\code{skips}}{
a numeric vector giving the number of visible solder skips.
}
}}
\source{
   John M. Chambers and Trevor J. Hastie eds. (1992)
  \emph{Statistical Models in S}, Wadsworth and Brooks/Cole,
  Pacific Grove, CA 1992.
}
\examples{
data(solder)
fit <- rpart(skips ~ Opening + Solder + Mask + PadType + Panel,
       data=solder, method='anova')
summary(residuals(fit))
plot(predict(fit),residuals(fit))
}
\keyword{datasets}

\eof
\name{spider}
\alias{spider}
\non_function{}
\title{Spider Data}
\description{
  The \code{spider} data frame has 28 rows and 18 columns. 
  The first 12 columns are abundances of different species of spiders
  and the next 6 are environmental data.
}
\usage{
data(spider)
}
\format{
This data frame contains the following columns:
\describe{
\item{\code{arct.lute, pard.lugu, zora.spin, pard.nigr, pard.pull,
 aulo.albi, troc.terr, alop.cune, pard.mont, alop.acce,
 alop.fabr, arct.peri }}{
numeric vectors giving the abundances of 12 species of spider
}
\item{\code{water, sand, moss, reft, twigs, herbs}}{
numeric vectors giving the values of 6 environmental characteristics
}}
}

\source{
   Van der Aart, P. J. and N. Smeeck-Enserink. 1975. 
   Correlations between distributions of hunting spiders (Lycosidae, Ctenidae) 
   and environmental characteristics in a dune area.  
   Netherlands Journal of Zoology. 25:1-45.

   These data were analysed using multivariate trees in
   De'ath, G. 2002. Multivariate Regression Trees: 
   A New Technique for Modelling Species-Environment Relationships.
   Ecology. 83(4):1103-1117
}

\examples{
data(spider)
fit<-mvpart(as.matrix(spider[,1:12])~water+twigs+reft+herbs+moss+sand,spider)
summary(fit)
}
\keyword{datasets}

\eof
\name{string.bounding.box}
\alias{string.bounding.box}
\title{
  String.bounding.box
}
\description{
  Internal function for Rpart
}

\details{
  \code{string.bounding.box} is to be used only internally.
}
\keyword{internal}


\eof
\name{sub.barplot}
\alias{sub.barplot}
\title{
  Sub.barplot
}
\description{
  Internal function for Rpart
}

\details{
  \code{sub.barplot} is to be used only internally.
}
\keyword{internal}


\eof
\name{summary.rpart}
\alias{summary.rpart}
\title{
  Summarize a Fitted Rpart Object 
}
\description{
  Returns a detailed listing of a fitted \code{rpart} object.
}
\usage{
\method{summary}{rpart}(object, cp=0, digits=getOption("digits"), file, \dots)
}
\arguments{
\item{object}{
  fitted model object of class \code{rpart}.  This is assumed to be the result
  of some function that produces an object with the same named
  components as that returned by the \code{rpart} function.
}
\item{digits}{
    Number of significant digits to be used in the result.
}
\item{cp}{
  trim nodes with a complexity of less than \code{cp} from the listing.
}
\item{file}{
  write the output to a given file name. (Full listings of a tree are
  often quite long).
}
\item{\dots}{
  arguments to be passed to or from other methods.
}}
\details{
  This function is a method for the generic function summary for class
  \code{"rpart"}.  It can be invoked by calling \code{summary}
  for an object of the appropriate class, or directly by calling
  \code{summary.rpart} regardless of the class of the object.
}
\seealso{
  \code{\link{summary}}, \code{\link{rpart.object}}, \code{\link{printcp}}.
}
\examples{
data(car.test.frame)
z.auto <- rpart(Mileage ~ Weight, car.test.frame)
summary(z.auto)
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{text.rpart}
\alias{text.rpart}
\title{
  Place Text on a Dendrogram 
}
\description{
  Labels the current plot of the tree dendrogram with text.
}
\usage{
\method{text}{rpart}function (x, splits = TRUE, which = 1, label = "yval", FUN = text, 
    all = FALSE, pretty = NULL, digits = getOption("digits") - 
        2, tadj = 0.65, stats = TRUE, use.n = FALSE, bars = TRUE, 
    xadj = 1, yadj = 1, bord = FALSE, big.pts = FALSE, \dots)
}
\arguments{
\item{x}{
  fitted model object of class \code{rpart}.  This is assumed to be the result
  of some function that produces an object with the same named
  components as that returned by the \code{rpart} function.
}
\item{splits}{
  logical flag.  If \code{TRUE} (default), then the splits in the tree are
  labeled with the criterion for the split.
}
\item{which}{
  labels splits 1 = center, 2 = left, 3 = right , 4 = both.  
}
\item{label}{
a column name of \code{x$frame};  values of this
will label the nodes.  For the \code{"class"} method,
\code{label="yval"} results in the factor levels
being used, \code{"yprob"} results in the probability of the winning factor
level being used, and 'specific yval level' results in the probability
of that factor level.   
}
\item{FUN}{
  the name of a labeling function, e.g. \code{text}.  
}
\item{all}{
  Logical.  If \code{TRUE}, all nodes are labeled, otherwise just
  terminal nodes.
}
\item{tadj}{
Adjustment of text above (or below) splits.
}

\item{pretty}{
  an integer denoting the extent to which factor levels in split labels
  will be abbreviated.  A value of (0) signifies no abbreviation.  A
  \code{NULL}, the default, signifies using elements of letters to represent
  the different factor levels.
}
\item{digits}{
  number of significant digits to include in numerical labels.
}
\item{stats}{
  If \code{TRUE} adds statistics to nodes.
}
\item{use.n}{
  If \code{TRUE} adds N to labels. 
  (\#events level1/ \#events level2/etc. for \code{class},
  \code{n} for \code{anova}, and \#events/n for \code{poisson} and \code{exp}).
}
\item{bars}{
  If \code{TRUE} adds barplots for multivariate regression trees.
}
\item{xadj, yadj}{
 varies the size of barplots for multivariate regression trees.
}
\item{bord}{
 Adds borders (boxes) to barplots for multivariate regression trees.
}
\item{big.pts}{
 Adds color coded points to nodes. Useful to track groups to PCA plot
(see \code{rpart.pca}).
}
\item{\dots}{
  Graphical parameters may also be supplied as arguments to this
  function (see \code{par}).
}}
\section{Side Effects}{
  the current plot of a tree dendrogram is labeled.
}
\seealso{
  \code{\link{text}}, \code{\link{plot.rpart}}, \code{\link{rpart}},
  \code{\link{post.rpart}}, \code{\link{abbreviate}} 
}
\examples{
data(car.test.frame)
z.auto <- rpart(Mileage ~ Weight, car.test.frame)
plot(z.auto)
text(z.auto, use.n=TRUE, all=TRUE)
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
\name{trclcomp}
\alias{trclcomp}
\title{Tree-Clustering Comparison}
\description{
  This function compares the within-group variation for groups formed by
  tree partitioning and unconstrained clustering.
  The results are plotted and returned invisibly.
}
\usage{
trclcomp(x, method = "com")
}

\arguments{
  \item{x}{ Rpart object with method "mrt" -- see \code{\link{rpart}}}
  \item{method}{ The clustering method for the unconstrained clustering
  -- see \code{\link[mva]{hclust}}}.
}

\details{
  The within-group variation for groups formed by tree partitioning and 
  unconstrained clustering are compared for all sizes of the hierarchy of tree
  partitions,   
}

\value{
  Returns a list (invisibly) of the within-tree and within-cluster variation for all tree sizes.
}

\references{ 

De'ath G. (2002)  
Multivariate Regression Trees : A New Technique for Constrained Classification Analysis.
Ecology 83(4):1103-1117.
  
  \author{ Glenn De'ath }
}
  
\examples{
data(spider)
fit <- mvpart(data.matrix(spider[,1:12])~herbs+reft+moss+sand+twigs+water,spider)  
trclcomp(fit)
}

\keyword{ multivariate }%-- one or more ...

\eof
\name{tree.depth}
\alias{tree.depth}
\title{
  Tree.depth
}
\description{
  Internal function for Rpart
}

\details{
  \code{tree.depth} is to be used only internally.
}
\keyword{internal}


\eof
\name{xdiss}
\alias{xdiss}
\title{Extendend Dissimilarity Measures}
\description{
  The function computes extended dissimilarity indices which are for long gradients
  have better good rank-order relation with gradient separation and are
  thus efficient in community ordination with multidimensional scaling.
}
\usage{
xdiss(data, dcrit = 1, dauto = TRUE, dinf = 0.5, method = "man", 
    use.min = TRUE, eps = 1e-04, replace.neg = TRUE, big = 10000,
    sumry = TRUE, full = FALSE, sq = FALSE) 
}

\arguments{
  \item{data}{ Data matrix}
  \item{dcrit}{ Dissimilarities < \code{dcrit} are considered to have no species in common
   and are recalculated.}
  \item{dauto}{ Automatically select tuning parameters -- recommended.}
  \item{method}{ Dissimilarity index }
  \item{use.min}{ Minimum dissimilarity of pairs of distances used -- recommended.}
  \item{dinf, eps, replace.neg, big}{ Internal parameters -- leave as is usually.}
  \item{sumry}{ Print summary of extended dissimilarities? }
  \item{full}{ Return the square dissimilarity matrix. }
  \item{sq}{ Square the dissimilarities -- useful for distance-based partitionong. }
}
\details{
  The function knows the same dissimilarity indices as \code{\link[mvpart]{gdist}}.
    
}

\value{
  Returns an object of class distance with attributes "Size" and "ok".
  "ok" is TRUE if rows are not disconnected (De'ath 1999).
}
\references{ 
  De'ath, G. (1999) 
  Extended dissimilarity: a method of robust estimation of ecological distances
  from high beta diversity data. \emph{Plant Ecology} 144(2):191-199.

  Faith, D.P, Minchin, P.R. and Belbin, L. (1987)
  Compositional dissimilarity as a robust measure of ecological
  distance. \emph{Vegetatio} 69, 57-68. }
\author{ Glenn De'ath }

\examples{
data(spider)
spider.dist <- xdiss(spider)
}
\keyword{ multivariate }%-- one or more ...

\eof
\name{xpred.rpart}
\alias{xpred.rpart}
\title{
  Return Cross-Validated Predictions 
}
\description{
  Gives the predicted values for an \code{rpart} fit, under
  cross validation, for a set of complexity parameter values.
}
\usage{
xpred.rpart(fit, xval=10, cp)
}
\arguments{
\item{fit}{
a \code{rpart} object. 
}
\item{xval}{
  number of cross-validation groups.  This may also be an explicit list of
  integers that define the cross-validation groups.
}
\item{cp}{
  the desired list of complexity values.  By default it is taken from the
  \code{cptable} component of the fit.
}}
\value{
  a matrix with one row for each observation and one column for each complexity
  value.
}
\details{
  Complexity penalties are actually ranges, not values.  If the
  \code{cp} values found in the table were \eqn{.36}, \eqn{.28},
  and \eqn{.13}, for instance, this means that the first row of the
  table holds for all complexity penalties in the range \eqn{[.36, 1]},
  the second row for \code{cp} in the range \eqn{[.28, .36)} and
  the third row for \eqn{[.13,.28)}.  By default, the geometric mean
  of each interval is used for cross validation.
}
\seealso{
\code{\link{rpart}} 
}
\examples{
data(car.test.frame)
fit <- rpart(Mileage ~ Weight, car.test.frame)
xmat <- xpred.rpart(fit)
xerr <- (xmat - car.test.frame$Mileage)^2
apply(xerr, 2, sum)   # cross-validated error estimate

# approx same result as rel. error from printcp(fit)
apply(xerr, 2, sum)/var(car.test.frame$Mileage) 
printcp(fit)
}
\keyword{tree}
% docclass is function
% Converted by Sd2Rd version 1.20.

\eof
